==> net.bluemind.p2.platform-4.9.3879.zip: store/types/mutations.js <==
// popup
export const IS_POPUP = "IS_POPUP";

// activeMessage
export const RESET_ACTIVE_MESSAGE = "RESET_ACTIVE_MESSAGE";
export const SET_ACTIVE_MESSAGE = "SET_ACTIVE_MESSAGE";

// partsData
export const RESET_PARTS_DATA = "RESET_PARTS_DATA";
export const SET_PART_DATA = "SET_PART_DATA";

// mailboxes
export const ADD_MAILBOXES = "ADD_MAILBOXES";
export const RESET_MAILBOXES = "RESET_MAILBOXES";

// folders
export const ADD_FOLDER = "ADD_FOLDER";
export const REMOVE_FOLDER = "REMOVE_FOLDER";
export const RESET_FOLDERS = "RESET_FOLDERS";
export const SET_ACTIVE_FOLDER = "SET_ACTIVE_FOLDER";
export const SET_UNREAD_COUNT = "SET_UNREAD_COUNT";
export const SET_FOLDER_EXPANDED = "SET_FOLDER_EXPANDED";
export const RESET_ACTIVE_FOLDER = "RESET_ACTIVE_FOLDER";
export const UPDATE_FOLDER = "UPDATE_FOLDER";
export const UPDATE_PATHS = "UPDATE_PATHS";
// message
export const ADD_ATTACHMENT = "ADD_ATTACHMENT";
export const ADD_FLAG = "ADD_FLAG";
export const ADD_MESSAGES = "ADD_MESSAGES";
export const DELETE_FLAG = "DELETE_FLAG";
export const MOVE_MESSAGES = "MOVE_MESSAGES";
export const REMOVE_ATTACHMENT = "REMOVE_ATTACHMENT";
export const REMOVE_MESSAGE_HEADER = "REMOVE_MESSAGE_HEADER";
export const REMOVE_MESSAGES = "REMOVE_MESSAGES";
export const SET_ATTACHMENT_ADDRESS = "SET_ATTACHMENT_ADDRESS";
export const SET_ATTACHMENT_ENCODING = "SET_ATTACHMENT_ENCODING";
export const SET_ATTACHMENT_HEADERS = "SET_ATTACHMENT_HEADERS";
export const SET_ATTACHMENT_PROGRESS = "SET_ATTACHMENT_PROGRESS";
export const SET_ATTACHMENT_STATUS = "SET_ATTACHMENT_STATUS";
export const SET_ATTACHMENTS = "SET_ATTACHMENTS";
export const SET_MESSAGE_BCC = "SET_MESSAGE_BCC";
export const SET_MESSAGE_CC = "SET_MESSAGE_CC";
export const SET_MESSAGE_COMPOSING = "SET_MESSAGE_COMPOSING";
export const SET_MESSAGE_DATE = "SET_MESSAGE_DATE";
export const SET_MESSAGE_FROM = "SET_MESSAGE_FROM";
export const SET_MESSAGE_HAS_ATTACHMENT = "SET_MESSAGE_HAS_ATTACHMENT";
export const SET_MESSAGE_HEADERS = "SET_MESSAGE_HEADERS";
export const SET_MESSAGE_INTERNAL_ID = "SET_MESSAGE_INTERNAL_ID";
export const SET_MESSAGE_INLINE_PARTS_BY_CAPABILITIES = "SET_MESSAGE_INLINE_PARTS_BY_CAPABILITIES";
export const SET_MESSAGE_IMAP_UID = "SET_MESSAGE_IMAP_UID";
export const SET_MESSAGES_LOADING_STATUS = "SET_MESSAGES_LOADING_STATUS";
export const SET_MESSAGE_PREVIEW = "SET_MESSAGE_PREVIEW";
export const SET_MESSAGE_SIZE = "SET_MESSAGE_SIZE";
export const SET_MESSAGES_STATUS = "SET_MESSAGES_STATUS";
export const SET_MESSAGE_SUBJECT = "SET_MESSAGE_SUBJECT";
export const SET_MESSAGE_TMP_ADDRESSES = "SET_MESSAGE_TMP_ADDRESSES";
export const SET_MESSAGE_TO = "SET_MESSAGE_TO";

//conversationList
export const RESET_CONVERSATION_LIST_PAGE = "RESET_CONVERSATION_LIST_PAGE";
export const SET_CONVERSATION_LIST = "SET_CONVERSATION_LIST";
export const SET_CONVERSATION_LIST_FILTER = "SET_CONVERSATION_LIST_FILTER";
export const SET_CONVERSATION_LIST_STATUS = "SET_CONVERSATION_LIST_STATUS";
export const SET_CONVERSATION_LIST_PAGE = "SET_CONVERSATION_LIST_PAGE";

//search
export const RESET_CURRENT_SEARCH_PATTERN = "RESET_CURRENT_SEARCH_PATTERN";
export const SET_CURRENT_SEARCH_DEEP = "SET_CURRENT_SEARCH_DEEP";
export const SET_CURRENT_SEARCH_FOLDER = "SET_CURRENT_SEARCH_FOLDER";
export const SET_CURRENT_SEARCH_PATTERN = "SET_CURRENT_SEARCH_PATTERN";
export const SET_HAS_MORE_RESULTS = "SET_HAS_MORE_RESULTS";
export const SET_SEARCH_QUERY_DEEP = "SET_SEARCH_QUERY_DEEP";
export const SET_SEARCH_QUERY_FOLDER = "SET_SEARCH_QUERY_FOLDER";
export const SET_SEARCH_QUERY_PATTERN = "SET_SEARCH_QUERY_PATTERN";

// messageCompose
export const MAX_MESSAGE_SIZE_EXCEEDED = "MAX_MESSAGE_SIZE_EXCEEDED";
export const RESET_COMPOSER = "RESET_COMPOSER";
export const SET_CORPORATE_SIGNATURE = "SET_CORPORATE_SIGNATURE";
export const SET_PERSONAL_SIGNATURE = "SET_PERSONAL_SIGNATURE";
export const SET_DISCLAIMER = "SET_DISCLAIMER";
export const SET_DRAFT_COLLAPSED_CONTENT = "SET_DRAFT_COLLAPSED_CONTENT";
export const SET_DRAFT_EDITOR_CONTENT = "SET_DRAFT_EDITOR_CONTENT";
export const SET_MAX_MESSAGE_SIZE = "SET_MAX_MESSAGE_SIZE";
export const SET_SAVED_INLINE_IMAGES = "SET_SAVED_INLINE_IMAGES";
export const SET_TEMPLATE_CHOOSER_TARGET = "SET_TEMPLATE_CHOOSER_TARGET";
export const SET_TEMPLATE_CHOOSER_VISIBLE = "SET_TEMPLATE_CHOOSER_VISIBLE";
export const SET_TEMPLATE_LIST_LOADING = "SET_TEMPLATE_LIST_LOADING";
export const SET_TEMPLATE_LIST_SEARCH_PATTERN = "SET_TEMPLATE_LIST_SEARCH_PATTERN";
export const SET_TEMPLATES_LIST = "SET_TEMPLATES_LIST";
export const SHOW_SENDER = "SHOW_SENDER";
export const UNSET_CORPORATE_SIGNATURE = "UNSET_CORPORATE_SIGNATURE";

// selection
export const UNSELECT_CONVERSATION = "UNSELECT_CONVERSATION";
export const SELECT_CONVERSATION = "SELECT_CONVERSATION";
export const SET_SELECTION = "SET_SELECTION";
export const UNSELECT_ALL_CONVERSATIONS = "UNSELECT_ALL_CONVERSATIONS";

// consultPanel
export const SET_BLOCK_REMOTE_IMAGES = "SET_BLOCK_REMOTE_IMAGES";
export const SET_CURRENT_EVENT = "SET_CURRENT_EVENT";
export const SET_CURRENT_EVENT_STATUS = "SET_CURRENT_EVENT_STATUS";

// folderList
export const RESET_FOLDER_FILTER_LIMITS = "RESET_FOLDER_FILTER_LIMITS";
export const SET_FOLDER_FILTER_PATTERN = "SET_FOLDER_FILTER_PATTERN";
export const SET_FOLDER_FILTER_RESULTS = "SET_FOLDER_FILTER_RESULTS";
export const SET_FOLDER_FILTER_LIMIT = "SET_FOLDER_FILTER_LIMIT";
export const SET_FOLDER_FILTER_LOADED = "SET_FOLDER_FILTER_LOADED";
export const SET_FOLDER_FILTER_LOADING = "SET_FOLDER_FILTER_LOADING";
export const TOGGLE_EDIT_FOLDER = "TOGGLE_EDIT_FOLDER";

// route
export const SET_ROUTE_FILTER = "SET_ROUTE_FILTER";
export const SET_ROUTE_FOLDER = "SET_ROUTE_FOLDER";
export const SET_ROUTE_MAILBOX = "SET_ROUTE_MAILBOX";
export const SET_ROUTE_SEARCH = "SET_ROUTE_SEARCH";

// conversations
export const ADD_CONVERSATIONS = "ADD_CONVERSATIONS";
export const REMOVE_CONVERSATIONS = "REMOVE_CONVERSATIONS";
export const RESET_CONVERSATIONS = "RESET_CONVERSATIONS";
export const SET_CONVERSATIONS_LOADING_STATUS = "SET_CONVERSATIONS_LOADING_STATUS";
export const SET_CURRENT_CONVERSATION = "SET_CURRENT_CONVERSATION";
export const UNSET_CURRENT_CONVERSATION = "UNSET_CURRENT_CONVERSATION";

// settings
export const SET_MAIL_THREAD_SETTING = "SET_MAIL_THREAD_SETTING";

// preview
export const SET_PREVIEW_PART_ADDRESS = "SET_PREVIEW_PART_ADDRESS";
export const SET_PREVIEW_MESSAGE_KEY = "SET_PREVIEW_MESSAGE_KEY";

// address weights
export const ADD_ADDRESS_WEIGHT = "ADD_ADDRESS_WEIGHT";
export const DELETE_ADDRESS_WEIGHTS = "DELETE_ADDRESS_WEIGHTS";
export const SET_ADDRESS_WEIGHT = "SET_ADDRESS_WEIGHT";
export const SET_ADDRESS_WEIGHTS = "SET_ADDRESS_WEIGHTS";

==> net.bluemind.p2.platform-5.4.2696.zip: store/types/mutations.js <==
// popup
export const IS_POPUP = "IS_POPUP";

// activeMessage
export const RESET_ACTIVE_MESSAGE = "RESET_ACTIVE_MESSAGE";
export const SET_ACTIVE_MESSAGE = "SET_ACTIVE_MESSAGE";

// partsData
export const RESET_PARTS_DATA = "RESET_PARTS_DATA";
export const SET_PART_DATA = "SET_PART_DATA";

// mailboxes
export const ADD_MAILBOXES = "ADD_MAILBOXES";
export const RESET_MAILBOXES = "RESET_MAILBOXES";

// folders
export const ADD_FOLDER = "ADD_FOLDER";
export const REMOVE_FOLDER = "REMOVE_FOLDER";
export const RESET_FOLDERS = "RESET_FOLDERS";
export const SET_ACTIVE_FOLDER = "SET_ACTIVE_FOLDER";
export const SET_UNREAD_COUNT = "SET_UNREAD_COUNT";
export const RESET_ACTIVE_FOLDER = "RESET_ACTIVE_FOLDER";
export const UPDATE_FOLDER = "UPDATE_FOLDER";
export const UPDATE_PATHS = "UPDATE_PATHS";

// message
export const ADD_ATTACHMENT = "ADD_ATTACHMENT";
export const ADD_FLAG = "ADD_FLAG";
export const ADD_MESSAGES = "ADD_MESSAGES";
export const DELETE_FLAG = "DELETE_FLAG";
export const MOVE_MESSAGES = "MOVE_MESSAGES";
export const REMOVE_ATTACHMENT = "REMOVE_ATTACHMENT";
export const REMOVE_MESSAGE_HEADER = "REMOVE_MESSAGE_HEADER";
export const REMOVE_MESSAGES = "REMOVE_MESSAGES";
export const SET_ATTACHMENT_ADDRESS = "SET_ATTACHMENT_ADDRESS";
export const SET_ATTACHMENT_HEADERS = "SET_ATTACHMENT_HEADERS";
export const SET_MESSAGE_BCC = "SET_MESSAGE_BCC";
export const SET_MESSAGE_CC = "SET_MESSAGE_CC";
export const SET_MESSAGE_COMPOSING = "SET_MESSAGE_COMPOSING";
export const SET_MESSAGE_DATE = "SET_MESSAGE_DATE";
export const SET_MESSAGE_FROM = "SET_MESSAGE_FROM";
export const SET_MESSAGE_HEADERS = "SET_MESSAGE_HEADERS";
export const SET_MESSAGE_INTERNAL_ID = "SET_MESSAGE_INTERNAL_ID";
export const SET_MESSAGE_IMAP_UID = "SET_MESSAGE_IMAP_UID";
export const SET_MESSAGES_LOADING_STATUS = "SET_MESSAGES_LOADING_STATUS";
export const SET_MESSAGE_LOADING_STATUS = "SET_MESSAGE_LOADING_STATUS";
export const SET_MESSAGE_PREVIEW = "SET_MESSAGE_PREVIEW";
export const SET_MESSAGE_SIZE = "SET_MESSAGE_SIZE";
export const SET_MESSAGES_STATUS = "SET_MESSAGES_STATUS";
export const SET_MESSAGE_REPLYTO = "SET_MESSAGE_REPLYTO";
export const SET_MESSAGE_STRUCTURE = "SET_MESSAGE_STRUCTURE";
export const SET_MESSAGE_SUBJECT = "SET_MESSAGE_SUBJECT";
export const SET_MESSAGE_TO = "SET_MESSAGE_TO";
export const SET_SUSPECTED_PHISHING = "SET_SUSPECTED_PHISHING";

//conversationList
export const RESET_CONVERSATION_LIST = "RESET_CONVERSATION_LIST";
export const RESET_CONVERSATION_LIST_PAGE = "RESET_CONVERSATION_LIST_PAGE";
export const SET_CONVERSATION_LIST = "SET_CONVERSATION_LIST";
export const SET_CONVERSATION_LIST_FILTER = "SET_CONVERSATION_LIST_FILTER";
export const SET_CONVERSATION_LIST_PAGE = "SET_CONVERSATION_LIST_PAGE";
export const SET_CONVERSATION_LIST_SORT = "SET_CONVERSATION_LIST_SORT";
export const SET_CONVERSATION_LIST_STATUS = "SET_CONVERSATION_LIST_STATUS";

//search
export const RESET_CURRENT_SEARCH_PATTERN = "RESET_CURRENT_SEARCH_PATTERN";
export const SET_CURRENT_SEARCH_DEEP = "SET_CURRENT_SEARCH_DEEP";
export const SET_CURRENT_SEARCH_FOLDER = "SET_CURRENT_SEARCH_FOLDER";
export const SET_CURRENT_SEARCH_PATTERN = "SET_CURRENT_SEARCH_PATTERN";
export const SET_HAS_MORE_RESULTS = "SET_HAS_MORE_RESULTS";
export const SET_SEARCH_QUERY_DEEP = "SET_SEARCH_QUERY_DEEP";
export const SET_SEARCH_QUERY_FOLDER = "SET_SEARCH_QUERY_FOLDER";
export const SET_SEARCH_QUERY_PATTERN = "SET_SEARCH_QUERY_PATTERN";

// messageCompose
export const ADD_FILE = "ADD_FILE";
export const RESET_COMPOSER = "RESET_COMPOSER";
export const SET_CORPORATE_SIGNATURE = "SET_CORPORATE_SIGNATURE";
export const SET_DISCLAIMER = "SET_DISCLAIMER";
export const SET_DRAFT_EDITOR_CONTENT = "SET_DRAFT_EDITOR_CONTENT";
export const SET_FILE_ADDRESS = "SET_FILE_ADDRESS";
export const SET_FILES = "SET_FILES";
export const SET_FILE_PROGRESS = "SET_FILE_PROGRESS";
export const SET_FILE_STATUS = "SET_FILE_STATUS";
export const SET_FILE_HEADERS = "SET_FILE_HEADERS";
export const SET_MAIL_TIPS = "SET_MAIL_TIPS";
export const SET_MAX_MESSAGE_SIZE = "SET_MAX_MESSAGE_SIZE";
export const SET_PERSONAL_SIGNATURE = "SET_PERSONAL_SIGNATURE";
export const SET_SAVE_ERROR = "SET_SAVE_ERROR";
export const SET_TEMPLATE_CHOOSER_TARGET = "SET_TEMPLATE_CHOOSER_TARGET";
export const SET_TEMPLATE_CHOOSER_VISIBLE = "SET_TEMPLATE_CHOOSER_VISIBLE";
export const SET_TEMPLATE_LIST_LOADING = "SET_TEMPLATE_LIST_LOADING";
export const SET_TEMPLATE_LIST_SEARCH_PATTERN = "SET_TEMPLATE_LIST_SEARCH_PATTERN";
export const SET_TEMPLATES_LIST = "SET_TEMPLATES_LIST";
export const SHOW_REPLY_TO = "SHOW_REPLY_TO";
export const SHOW_SENDER = "SHOW_SENDER";
export const UNSET_CORPORATE_SIGNATURE = "UNSET_CORPORATE_SIGNATURE";
export const RESET_FILES = "RESET_FILES";
export const SIGNATURE_TOGGLED = "SIGNATURE_TOGGLED";
export const SHOW_SEND_LATER_MODAL = "SHOW_SEND_LATER_MODAL";
export const SET_INVALID_RECIPIENT_MODAL = "SET_INVALID_RECIPIENT_MODAL";
export const SET_INPUT_VALUE_FIELD_TO = "SET_INPUT_VALUE_FIELD_TO";
export const SET_INPUT_VALUE_FIELD_CC = "SET_INPUT_VALUE_FIELD_CC";
export const SET_INPUT_VALUE_FIELD_BCC = "SET_INPUT_VALUE_FIELD_BCC";
export const SET_INPUT_VALUE_FIELD_REPLYTO = "SET_INPUT_VALUE_FIELD_REPLYTO";
export const SET_INVALID_RECIPIENT_ALERT = "SET_INVALID_RECIPIENT_ALERT";

// selection
export const UNSELECT_CONVERSATION = "UNSELECT_CONVERSATION";
export const SELECT_CONVERSATION = "SELECT_CONVERSATION";
export const SET_SELECTION = "SET_SELECTION";
export const UNSELECT_ALL_CONVERSATIONS = "UNSELECT_ALL_CONVERSATIONS";

// consultPanel
export const SET_BLOCK_REMOTE_IMAGES = "SET_BLOCK_REMOTE_IMAGES";
export const SET_CURRENT_EVENT = "SET_CURRENT_EVENT";
export const SET_CURRENT_EVENT_STATUS = "SET_CURRENT_EVENT_STATUS";

// folderList
export const RESET_FOLDER_FILTER_LIMITS = "RESET_FOLDER_FILTER_LIMITS";
export const SET_FOLDER_FILTER_PATTERN = "SET_FOLDER_FILTER_PATTERN";
export const SET_FOLDER_FILTER_RESULTS = "SET_FOLDER_FILTER_RESULTS";
export const SET_FOLDER_FILTER_LIMIT = "SET_FOLDER_FILTER_LIMIT";
export const SET_FOLDER_FILTER_LOADED = "SET_FOLDER_FILTER_LOADED";
export const SET_FOLDER_FILTER_LOADING = "SET_FOLDER_FILTER_LOADING";
export const TOGGLE_EDIT_FOLDER = "TOGGLE_EDIT_FOLDER";
export const SET_COLLAPSED_TREE = "SET_COLLAPSED_TREE";
export const SET_FOLDER_EXPANDED = "SET_FOLDER_EXPANDED";

// route
export const SET_ROUTE_FILTER = "SET_ROUTE_FILTER";
export const SET_ROUTE_FOLDER = "SET_ROUTE_FOLDER";
export const SET_ROUTE_MAILBOX = "SET_ROUTE_MAILBOX";
export const SET_ROUTE_SEARCH = "SET_ROUTE_SEARCH";
export const SET_ROUTE_SORT = "SET_ROUTE_SORT";

// conversations
export const ADD_CONVERSATIONS = "ADD_CONVERSATIONS";
export const REMOVE_CONVERSATIONS = "REMOVE_CONVERSATIONS";
export const RESET_CONVERSATIONS = "RESET_CONVERSATIONS";
export const SET_CONVERSATIONS_LOADING_STATUS = "SET_CONVERSATIONS_LOADING_STATUS";
export const SET_CURRENT_CONVERSATION = "SET_CURRENT_CONVERSATION";
export const UNSET_CURRENT_CONVERSATION = "UNSET_CURRENT_CONVERSATION";

// settings
export const SET_MAIL_THREAD_SETTING = "SET_MAIL_THREAD_SETTING";

// preview
export const RESET_PREVIEW = "RESET_PREVIEW";
export const SET_PREVIEW_FILE_KEY = "SET_PREVIEW_FILE_KEY";
export const SET_PREVIEW_MESSAGE_KEY = "SET_PREVIEW_MESSAGE_KEY";
export const SET_PREVIEW_VISIBLE = "SET_PREVIEW_VISIBLE";

// appData (automatically added by vuex plugin)
export const INCREASE_ADDRESS_WEIGHT = "INCREASE_ADDRESS_WEIGHT";
export const DELETE_ADDRESS_WEIGHTS = "DELETE_ADDRESS_WEIGHTS";
export const EXCLUDE_ADDRESS = "EXCLUDE_ADDRESS";
export const SET_SHOW_FORMATTING_TOOLBAR = "SET_SHOW_FORMATTING_TOOLBAR";
export const SET_WIDTH = "SET_WIDTH";
